@@ -99,7 +99,7 @@ KviMdiManager::KviMdiManager(TQWidget * parent,KviFrame * pFrm,const char * name
 	setFocusPolicy(TQ_NoFocus);
 	viewport()->setFocusPolicy(TQ_NoFocus);
 #endif
-	
+
 	connect(g_pApp,TQT_SIGNAL(reloadImages()),this,TQT_SLOT(reloadImages()));
 }
 
@@ -210,11 +210,11 @@ void KviMdiManager::setTopChild(KviMdiChild *lpC,bool bSetFocus)
 			pOldTop->captionLabel()->setActive(false);
 			if(pOldTop->m_state != KviMdiChild::Maximized)pMaximizedChild=0;
 		}
-		
+
 		m_pZ->setAutoDelete(true);
 		m_pZ->append(lpC);
 
-		if(pMaximizedChild)lpC->maximize(); //do not animate the change	
+		if(pMaximizedChild)lpC->maximize(); //do not animate the change
 		lpC->raise();
 		if(pMaximizedChild)pMaximizedChild->restore();
 	}
@@ -227,7 +227,7 @@ void KviMdiManager::setTopChild(KviMdiChild *lpC,bool bSetFocus)
 			/*
 			if(topLevelWidget()->isActiveWindow())
 			{
-				
+
 			}
 			*/
 		}
@@ -337,7 +337,7 @@ void KviMdiManager::maximizeChild(KviMdiChild * lpC)
 		// make sure that the child is focused
 		lpC->setFocus();
 	}
-	
+
 	// fixme: we could hide all the other children now!
 }
 
@@ -554,9 +554,9 @@ void KviMdiManager::enterSDIMode(KviMdiChild *lpC)
 	if(!m_pSdiCloseButton)
 	{
 		KviMenuBar * b = m_pFrm->mainMenuBar();
-	
+
 		TQWidget * pButtonParent;
-	
+
 #ifdef COMPILE_USE_QT4
 		m_pSdiControls = new KviTalHBox(b);
 		m_pSdiControls->setMargin(0);
@@ -601,7 +601,7 @@ void KviMdiManager::enterSDIMode(KviMdiChild *lpC)
 		m_pSdiCloseButton->show();
 #endif
 		emit enteredSdiMode();
-		
+
 		setVScrollBarMode(KviTalScrollView::AlwaysOff);
 		setHScrollBarMode(KviTalScrollView::AlwaysOff);
 	}
@@ -707,17 +707,17 @@ void KviMdiManager::fillWindowPopup()
 	int ids[KVI_NUM_TILE_METHODS];
 	ids[KVI_TILE_METHOD_ANODINE] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Anodine's Full Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_ANODINE],KVI_TILE_METHOD_ANODINE);
-	ids[KVI_TILE_METHOD_PRAGMA4HOR] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma'sQt::Horizontal 4-Grid")));
+	ids[KVI_TILE_METHOD_PRAGMA4HOR] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma's Horizontal 4-Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_PRAGMA4HOR],KVI_TILE_METHOD_PRAGMA4HOR);
-	ids[KVI_TILE_METHOD_PRAGMA4VER] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma'sQt::Vertical 4-Grid")));
+	ids[KVI_TILE_METHOD_PRAGMA4VER] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma's Vertical 4-Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_PRAGMA4VER],KVI_TILE_METHOD_PRAGMA4VER);
-	ids[KVI_TILE_METHOD_PRAGMA6HOR] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma'sQt::Horizontal 6-Grid")));
+	ids[KVI_TILE_METHOD_PRAGMA6HOR] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma's Horizontal 6-Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_PRAGMA6HOR],KVI_TILE_METHOD_PRAGMA6HOR);
-	ids[KVI_TILE_METHOD_PRAGMA6VER] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma'sQt::Vertical 6-Grid")));
+	ids[KVI_TILE_METHOD_PRAGMA6VER] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma's Vertical 6-Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_PRAGMA6VER],KVI_TILE_METHOD_PRAGMA6VER);
-	ids[KVI_TILE_METHOD_PRAGMA9HOR] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma'sQt::Horizontal 9-Grid")));
+	ids[KVI_TILE_METHOD_PRAGMA9HOR] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma's Horizontal 9-Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_PRAGMA9HOR],KVI_TILE_METHOD_PRAGMA9HOR);
-	ids[KVI_TILE_METHOD_PRAGMA9VER] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma'sQt::Vertical 9-Grid")));
+	ids[KVI_TILE_METHOD_PRAGMA9VER] = m_pTileMethodPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TILEWINDOWS)),(__tr2qs("Pragma's Vertical 9-Grid")));
 	m_pTileMethodPopup->setItemParameter(ids[KVI_TILE_METHOD_PRAGMA9VER],KVI_TILE_METHOD_PRAGMA9VER);
 
 	if(KVI_OPTION_UINT(KviOption_uintTileMethod) >= KVI_NUM_TILE_METHODS)KVI_OPTION_UINT(KviOption_uintTileMethod) = KVI_TILE_METHOD_PRAGMA9HOR;
@@ -831,7 +831,7 @@ void KviMdiManager::cascadeMaximized()
 	updateScrollBars();
 	g_pApp->sendPostedEvents();
 	if(g_pApp->closingDown())return;
-	
+
 	int idx=0;
 	KviPointerList<KviMdiChild> list(*m_pZ);
 
@@ -863,7 +863,7 @@ void KviMdiManager::expandVertical()
 	updateScrollBars();
 	g_pApp->sendPostedEvents();
 	if(g_pApp->closingDown())return;
-	
+
 	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
@@ -889,7 +889,7 @@ void KviMdiManager::expandHorizontal()
 	updateScrollBars();
 	g_pApp->sendPostedEvents();
 	if(g_pApp->closingDown())return;
-	
+
 	KviPointerList<KviMdiChild> list(*m_pZ);
 	list.setAutoDelete(false);
 	while(!list.isEmpty())
