@@ -160,7 +160,7 @@ const int widgettypes_cod[] = {
 		!fn: $geometry()
 		Returns the widget geometry in this form:[br]
 		x, y, width, height.
-		!fn: $setGeometry(<x_or_array>,[<y>,<width>,<heigth>])
+		!fn: $setGeometry(<x_or_array>,[<y>,<width>,<height>])
 		Sets the geometry of this widget. <x> and <y> are relative
 		to the parent widget or to the desktop (if this widget is
 		a toplevel one). All the parameters are in pixels.
